/* 
 Copyright 2008 Foxmarks Inc.

 foxmarks-uitools.js: Various and sundry UI functions. 

 */


function FoxmarksOpenWindowByType(inType, uri, features, args) {
    var wm = Cc['@mozilla.org/appshell/window-mediator;1'].
        getService(Ci.nsIWindowMediator);
    var topWindow = wm.getMostRecentWindow(inType);

    if (topWindow) {
        topWindow.focus();
    } else {
        topWindow = wm.getMostRecentWindow(null);
        var win = topWindow.openDialog(uri, "_blank", features || "chrome",
            args);
    }
}

function FoxmarksOpenInNewTab(url, focus) {
    var wm = Cc['@mozilla.org/appshell/window-mediator;1'].
        getService(Ci.nsIWindowMediator);
    var topWindow = wm.getMostRecentWindow('navigator:browser');
    if (topWindow) {
        var content = topWindow.document.getElementById('content');
        content.selectedTab =
            content.addTab(url);
        if (focus) {
            topWindow.focus();
        }
    }
}

function FoxmarksOpenInNewWindow(url) {
    openDialog("chrome://browser/content/browser.xul", "_blank",
        "chrome,all,dialog=no", url);
}

function OpenFoxmarksSettingsDialog(pane) {
    FoxmarksOpenWindowByType("foxmarks:settings",
        "chrome://foxmarks/content/foxmarks-dialog.xul", 
        "chrome,toolbar,centerscreen",
        [pane || "foxmarks-mainpane"]);
}

function MyFoxmarks() {
    FoxmarksOpenInNewTab("http://my.foxmarks.com/", true);
}

function FoxmarksOpenWizard(manual, skipAuth) {
    if (skipAuth) {
        FoxmarksOpenWindowByType("foxmarks:setup",
            "chrome://foxmarks/content/foxmarks-setup.xul",
            "chrome,centerscreen,dialog=no", manual);
    } else {
        FoxmarksOpenWindowByType("foxmarks:login", 
            "chrome://foxmarks/content/foxmarks-login.xul",
            "chrome,centerscreen,dialog=no", manual);
    }
}

function FoxmarksOnWizardCancel() {
    var ps = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
        .getService(Components.interfaces.nsIPromptService);

    var checkResult = {};
    checkResult.value = gSettings.wizardSuppress;
    var sb = Bundle();

    var ret = ps.confirmCheck(window, sb.GetStringFromName("title.cancelsetup"),
            sb.GetStringFromName("msg.cancelsetup"),
            sb.GetStringFromName("msg.nowizard"),
            checkResult);

    gSettings.wizardSuppress = checkResult.value;

    return ret;
}


function Synch() {
    PerformAction("synch");
}

function FoxmarksOpenStatusWindow() {
    PerformAction("showStatus");
}

function PerformAction(action, arg) {
    var retval = { helpurl: null };

    try {
        var win = window.openDialog(
            "chrome://foxmarks/content/foxmarks-progress.xul", "_blank",
            "chrome,dialog,modal,centerscreen", action, retval, arg);
        if (retval.helpurl) {
            FoxmarksOpenInNewWindow(retval.helpurl);   
        }
    } catch (e) {
        alert(e);
    }
    if (retval.status == 401) {
        alert(Bundle().GetStringFromName("msg.invalidcredentials"));
    }
    return retval.status;
}

var serviceObserver = {
    os: Cc["@mozilla.org/observer-service;1"].
        getService(Ci.nsIObserverService),

    observe: function(subject, topic, data) {
        var result = eval("(" + data + ")");
        if (this.text) {
            this.text.value = result.msg;
        }
        if (result.status != 1) {
            this.os.removeObserver(this, "foxmarks-service");
            if (this.spinner) {
                this.spinner.hidden = true;
            }
            if (this.callback) {
                var callback = this.callback;
                this.callback = null;
                callback(result);
            }
        }
    },

    start: function(text, spinner, callback) {
        this.os.addObserver(serviceObserver, "foxmarks-service", false);
        this.text = text;
        this.spinner = spinner;
        this.callback = callback;
        if (this.spinner) {
            this.spinner.hidden = false;
        }
    }
}

function FetchProfileNames(text, spinner, menuPopup, callback) {
    var fms = Cc["@foxcloud.com/extensions/foxmarks;1"].
        getService(Ci.nsIFoxmarksService);
    serviceObserver.start(text, spinner, FetchProfileNamesCallback);
    if (!fms.getProfileNames()) {
        callback({status: 2, msg: "Whoops! We're busy!" });
    }

    function FetchProfileNamesCallback(response) {
        if (response.profiles) {
            var profiles = response.profiles;
            var count = 0;
            for (var i = 1; i < menuPopup.childNodes.length; ++i) {
                if (profiles[String(i)]) {
                    var name = profiles[String(i)];
                    menuPopup.childNodes[i].label = name;
                    menuPopup.childNodes[i].hidden = false;
                    count++;
                } else {
                    menuPopup.childNodes[i].hidden = true;
                }
            }
            if (callback) {
                callback({ status: response.status, count: count, 
                        profiles: profiles });
            }
        }
    }
}

function FetchAccountStatus(text, spinner, callback) {
    var fms = Cc["@foxcloud.com/extensions/foxmarks;1"].
        getService(Ci.nsIFoxmarksService);
    serviceObserver.start(text, spinner, callback);
    fms.status();
}
